# maeson


[![image](https://img.shields.io/pypi/v/maeson.svg)](https://pypi.python.org/pypi/maeson)
[![image](https://img.shields.io/conda/vn/conda-forge/maeson.svg)](https://anaconda.org/conda-forge/maeson)


**Geospatial software for raster and point cloud processing.**


-   Free software: MIT License
-   Documentation: https://dzfinch.github.io/maeson
    

## Features

-   TODO
